
.TH CHTEX 1 12/16/89 
.SH NAME
chtex \- part of the Chinese TeX system

.SH SYNOPSIS

.B chtex 
\- a preprocessor for TeX documents containing Chinese

.SH DESCRIPTION
The 
.B chtex 
program is part of Chinese TeX, a system
for printing TeX documents
that contain Chinese characters.  Chinese TeX
is an extension of
the pre-existing TeX system.  In addition to TeX and the
.B chtex  
program, Chinese TeX
requires some additional software and a Postscript printer. 

.PP
Apart from Chinese TeX, the
.B chtex
program can also be used as a preprocessor for Scribe and WStroff
documents which contain Chinese characters.  Those applications
are not described in this man page.  
They are described in the documentation file 
.I chtex.doc
which can be found elsewhere (see below).
.PP
In this man page, we confine ourselves to a 
brief outline of how to use
.B chtex
to print Chinese TeX documents.

.SH USAGE
Here is a 6-step outline of how to create and print
a Chinese TeX document.  
Steps (2) through (5) have been automated 
in a shell script called
.B cctex.
For more information about 
.B cctex,
see the appropriate man page.
.PP
(1) The first step is to 
create a Chinese TeX file called, for example,
.I foo.tex.  
The file 
.I foo.tex
is just like an ordinary  
.I .tex 
file, except that 
.I foo.tex
may contain Chinese characters.
.PP
The Chinese characters in 
.I foo.tex
must be in CCDOS
format.  This means that each character is represented by a 
code consisting of two consecutive
8-bit bytes, and each of these two bytes has 
its high bit set to 1.  The 
two-byte character codes are in accordance with the Guo2-Biao1
standard.  Except for the presence of Chinese characters codes,
.I foo.tex 
looks just like an ordinary 
.I .tex 
file.  In particular,
.I foo.tex 
may invoke any of the usual TeX commands and macros.  
Simple examples of Chinese TeX files can be found with the other 
.B chtex 
documentation (see below).
.PP
Except for the Chinese characters codes, all
of the bytes in 
.I foo.tex 
are in the standard ASCII range, from 1 to 127.
Such a byte has its high bit set to 0.  Thus 
.B chtex
will be able to distinguish Chinese character codes from
the other bytes in 
.I foo.tex
.PP
In order to create 
.I foo.tex, 
it is probably convenient to use
a plain-vanilla CCDOS editor.  
Your editor should be able to produce a mixture of 
Chinese character codes and standard ASCII.
For example, on a PC you can use Byx or Chinese Wordstar
in "non-document" mode.  
On a Macintosh, analogous editors are available.
Here on the Math Department Suns,
you can use an interesting program called
.B chtext 
(not to be confused with 
.B chtex).
Documentation for
.B chtext 
can be found with the
.B chtex
documentation (see below).
.PP
(2)  Once you have created 
.I foo.tex,
it should take only a few minutes to render 
it into Postscript for printing.  First, you must process
.I foo.tex
using
.B chtex.
The appropriate command is

.I     chtex foo.tex

and this will create two output files,
.I foo.hdr   
and
.I foo.chtex.
Both of these files will be needed later.
.PP
(3)  The next step is to process
.I foo.chtex
using the pre-existing TeX system.  
For example, you can issue the command 

.I     tex foo.chtex.

If successful, your
.B tex 
command will produce another output file called
.I foo.dvi.
(For more information, see the
.B tex
man page.)
.PP
(4)  The next step is to process 
.I foo.dvi
using J. B. Wang's specially hacked version of 
.B dvi2ps, 
the public domain dvi-to-Postscript converter.
The appropriate command is

.I     dvi2ps foo.dvi > foo.lps

and of course this produces yet another output file, 
.I foo.lps.
.PP
(5)  The next step is to combine 
.I foo.hdr
and
.I foo.lps
into one big output file.  The appropriate command is

.I     cat foo.hdr foo.lps > foo.ps

and the output of this step is a complete Postscript file,
.I foo.ps.
.PP
(6)  The last step is to print the Postscript file on a
Postscript printer.  The appropriate command might be

.I     lpr foo.ps

after which, finally, you can go to the printer and
watch your finished document emerge.  Good luck!

.SH OPTIONS
There are a number of options for 
.B chtex
that are not covered in this man page.  
For further information, 
see the documentation files.

.SH LIBRARIES
Currently the Chinese TeX system is not really installed
for general use.  
Instead, Stephen G. Simpson has installed it in his home
directory, /home/boole/simpson.  
This implies that, before you
can use the system, you will have
to set certain environment variables appropriately so that
your shell will be able to find
.B chtex
and
.B dvi2ps,
and so that
.B chtex, tex,
and
.B dvi2ps
will be able to find the library files that they need.
.PP
First, put Simpson's personal directory for executables
into your path.  The appropriate command might be 

.I   set path=(/home/boole/simpson/bin/sun3 $path)

or

.I   set path=(/home/boole/simpson/bin/sun4 $path)

depending on whether you are logged in to a Sun 3 or a Sun4.
.PP
In addition, you must put Simpson's personal TeX font directory
into your TEXFONTS path.  
(TEXFONTS is the path of directories where
.B tex
looks for fonts.  See the man page for 
.B tex.)
The appropriate command might be

.I " setenv TEXFONTS                                              "

.I "  .:/home/boole/simpson/lib/tex/fonts:/usr/local/lib/tex/fonts"

which is supposed to be all on one line.
Finally, you should put Simpson's personal TeX macro directory
into your TeX macro path.  The appropriate command might be

.I " setenv TEXINPUTS                                               "

.I "  .:/home/boole/simpson/lib/tex/macros:/usr/local/lib/tex/macros"

and again this is all supposed to go on one line.

.SH DOCUMENTATION
There is documentation for
.B chtex 
and 
.B dvi2ps 
in
.I /home/boole/simpson/doc.  
The source code, along with other useful information, is in
.I /home/boole/simpson/src.
The latest version of the 
.B chtex 
man page will be maintained as 
.I chtex.1 
in 
.I /home/boole/simpson/man/man1
and
.I /home/boole/simpson/man/cat1.
There is also a man page for
.B dvi2ps 
in the same directories.
.PP
In order to use the Chinese TeX system as described 
here, you must have an account 
on the Penn State Math Department
Computer Network.
If you have any questions, try reading the
documention.  If that doesn't help, try
sending mail to simpson@boole.math.psu.edu or to the
author of
.B chtex,
J. B. Wang.
 
.SH AUTHOR
J. B. Wang
.PP
jwang@pittvms.bitnet
.PP
Dr. Wang would appreciate feedback from users.
.SH BUGS
This software is still under development and
fairly buggy.  If 
.B chtex
gets into trouble, try hitting <Return>.



