
.TH CHTEXT 1 "22 December 1989"
.SH NAME
chtext \- edit CCDOS files (mixed Chinese and ASCII)
.SH SYNOPSIS
.I chtext foo.pin foo 

(interactively convert a pinyin file to a CCDOS file)

.I chtext foo foo.pin -p 

(convert a CCDOS file to an annotated pinyin file)

.I chtext foo -e

(edit a CCDOS file in line-editor mode)

.SH DESCRIPTION
.B Chtext
is a fairly sophisticated program whose purpose
is to help you create and modify CCDOS files.
Rapid input is achieved by interactive batch conversion of
pinyin syllables into Chinese characters.  
Multi-syllable combinations are stored 
in an external dictionary which is updated after each session.

.SH "FILE FORMATS"
.PP
A CCDOS file
is like a standard ASCII file except that, 
in addition to standard ASCII characters, 
it may also contain Chinese characters.  
Each Chinese character is represented by 
a code consisting of two consecutive
8-bit bytes, each of the two bytes having its high bit set to 1.
These bytes are easily distinguished from standard ASCII
bytes, since the latter have their high bits set to 0.
The Chinese character codes are in accordance with the Guo2-Biao1
standard.
.PP
There is a particular kind of CCDOS file
known as a Chinese TeX file.  Such files are named with a
.I .tex
extension and contain TeX commands.
They are used as input for the Chinese TeX system.
Even if a CCDOS file 
.I foo
does not contain any
TeX commands, it can be renamed to
.I foo.tex
and processed for printing as if it were a Chinese TeX file.
More information about Chinese TeX can be found in the
.B chtex
man page.  (Note that
.B chtex
is not to be confused with
.BR chtext .)
.PP
The purpose of
.B chtext
is to help you create CCDOS files.
Roughly speaking, this is accomplished by conversion
of pinyin files into CCDOS.
A pinyin file is a standard ASCII file, 
i.e. it contains only standard ASCII characters.  
In particular, a pinyin file does not contain Chinese characters.
The pinyin file format is further described 
in the tutorial below.

.SH TUTORIAL
.PP
One limitation of
.B chtext
is that it runs only on a VT100 terminal or in a VT100 window.
For instance, you can use
.B chtext
when dialing in from a PC with VT100 emulation software.
Here on the Penn State Math Department Suns,
you can get a VT100 window by running
.B vtem
inside a shelltool.  For this, the simplest command is

.I shelltool -Ww 80 -Wh 24 vtem &

but you may consult the 
.B vtem 
man page for more details.
.PP
There are several different ways to use
.BR chtext .
In this man page, we explain how to use 
.B chtext
in interactive batch mode.  
This way is the easiest and most efficient.  
Other ways to use
.B chtext
are described in the documentation (see below).
.PP
You begin by using a standard ASCII editor (such as
.B emacs
or
.BR vi )
to create a pinyin file.  
This is a standard ASCII file which may contain
both ASCII text and pinyin syllables.
You then use 
.B chtext 
in interactive batch mode 
to go through the pinyin syllables
and select a Chinese character to go with each of them.
This selection process is required 
because typically a pinyin syllable
matches several different Chinese characters.  The result
of the selection process is a CCDOS file.
.PP
For example, suppose that your pinyin file is called
.I foo.pin
and consists of the single line

 \\Zw han4 zi4 

where \\Zw is an escape sequence meaning "begin Chinese mode,"
and han4 and zi4 are pinyin syllables.  
If you get into a VT100 window and issue the command

.IR "chtext foo.pin foo" ,

you are presented with five Chinese characters, each of
which has the pronunciation han4.  
If the character you want is not among those presented,
press the space bar to see more characters.
Fortunately, the character you want is the third one on the initial
screen.  You select it by pressing 3.  Next, you are presented with
five characters having the pronunciation zi4.  You select the second
one by pressing 2.  Finally, the program asks if you would like to see
the file that you have created.  
You type "yes".  The program displays

  %                    %%
   %         %     %    %%    %
   %% %%%%%%%%%   %%%%%%%%%%%%%%
   %%       %%   %%%         %%                                                
 %     %    %%    %        % %
  %    %    %%       %%%%%%%%                                                  
  %%    %  %%             %%
  %%  % %  %%            %%                                                    
     %  %% %            %%    %
    %%   %%%      %%%%%%%%%%%%%%
 % %%    %%             %%
  %%%    %%%            %%
  %%    %% %%           %%
  %%%  %%   %%%         %%
   %% %%     %%%      %%%%
   % %        %         %

and quits.  You now have a small CCDOS file, 
.IR foo , 
consisting of the CCDOS codes for these two characters.
.PP
This method of input, 
creation of a pinyin file followed by
interactive batch conversion of pinyin syllables into Chinese
characters, 
is much faster and easier than
the use of ordinary CCDOS editors such as Chinese Wordstar.
.PP
In addition to the \\Zw escape sequence, the pinyin file
.I foo.pin
may contain other escape sequences and
.B chtext
commands.  For instance, 
\\As is an escape sequence meaning "begin ASCII mode,"
and # is a special character indicating a space
in Chinese mode.  
This permits you to mix Chinese and ASCII on the same
line, as in

\\As ASCII.  \\Zw zhe4 shi4 zhong1 wen2.##\\As ASCII again.

Other special characters and escape sequences are discussed below.
.PP
Note that an escape sequence such as \\Zw or \\As
must be followed by a standard ASCII space.
This space is in fact part of the escape sequence.
.PP
If you want to modify your CCDOS file, you can use 
.B chtext
to convert it back to a pinyin
file, which can then be edited
using a standard ASCII editor.  
The pinyin syllables in the converted file 
will be capitalized and annotated
to identify them as unique Chinese characters in the internal
.B chtext
dictionary.  With the above example, the command

.I chtext foo foo.PIN -p

produces a new pinyin file, 
.IR foo.PIN , 
which looks something like

\\As ASCII.  \\Zw Zhe4zz Shi4rt Zhong1 Wen2.##\\As ASCII again.

.PP
You can use your plain ASCII editor to modify
.I foo.PIN 
by moving text, deleting text, and adding text.  
The text which you add may include
Chinese mode pinyin syllables, annotated or unannotated.
When you have modified
.I foo.PIN
to your satisfaction, go to a VT100 window and issue the command

.I chtext foo.PIN foo

to convert foo.PIN back into a CCDOS file.  This will involve
selecting Chinese characters to go with the newly added, unannotated,
pinyin syllables.
.PP
In practice, 
.I foo.PIN
can be the same file as
.IR foo.pin .
.PP
If you only want to modify the ASCII part of your CCDOS file,
you needn't go through the above-described
CCDOS-to-pinyin-to-CCDOS conversion process.  
Instead, you can directly edit your CCDOS file
using a plain ASCII editor such as 
.BR emacs .
Be warned however that 
.B vi
will not work for this purpose.  In fact, 
.B vi 
will destroy your CCDOS file by stripping the high bits.
.PP
(Note: On the Penn State Math Department Suns, 
.B emacs
is called
.BR gnuemacs .)
.PP
It is also possible to use
.B chtext
in line editor mode 
to directly edit Chinese characters in a CCDOS file.
The appropriate command is

.IR "chtext foo -e" .
 
For this and much more information on how to use
.BR chtext ,
see the documentation.

.SH "EXTERNAL DICTIONARY"
.PP
During interactive pinyin processing,
.B chtext
is able to recognize many combinations consisting of 
two or more pinyin syllables separated by hyphens.  
For example, 
.B chtext
can recognize the two-syllable combination wo3-men2 ("we").  
The advantage of this is that
wo3-men2 corresponds
to a unique combination of two Chinese characters, 
even though men2 by itself is ambiguous and could indicate 
any of four different Chinese characters in the internal 
.B chtext
dictionary.  Thus, when
.B chtext
encounters wo3-men2, 
it is intelligent enough to forego the
Chinese character selection process.  
Instead, 
.B chtext 
presents you with the correct two-character combination.
This feature saves considerable time and effort.
.PP
In order to use this feature of
.BR chtext , 
you need a personal, external dictionary 
of multi-syllable pinyin combinations.
This dictionary is a standard ASCII file
for which you have read-write permission, 
located somewhere in your home directory.  
In addition, you must set an environment variable
CHTEXTDIC to point to your personal dictionary file.
For example, my personal dictionary file is named 
.I chtext.dic 
and is located in 
.IR /home/boole/simpson/lib/ch .
To set the CHTEXTDIC environment variable, I use

.I setenv CHTEXTDIC /home/boole/simpson/lib/ch/chtext.dic

and this line is in my 
.I .login 
file.
.PP
Initially, you can copy 

.I /usr/local/doc/ch/examples/chtext.dic 

or someone else's CHTEXTDIC file 
into your own directory for your own use. 
Subsequently, every time you use
.BR chtext ,
your CHTEXTDIC file will be
updated at the end of each session, 
automatically taking note of the
multi-character combinations which you have used.
Thus, as time passes, 
your CHTEXTDIC file will become more personalized.
This will save you much time and effort.

.SH "ESCAPE SEQUENCES AND COMMANDS"
.PP
Your pinyin files may contain various escape sequences and
special commands which are recognized by 
.BR chtext .
.PP
Each of the following escape sequences 
must be followed by a standard ASCII space, 
which is in fact part of the escape sequence.

 \\As    begin ASCII mode
 \\Zw    begin Chinese mode
 \\CZw   begin pure Chinese mode
 \\aS    begin Chinese ASCII mode 
           (ASCII characters in Guo2-Biao1 format)
 \\jp    begin Japanese Hiragana mode
 \\Jp    begin Japanese Katakana mode
 \\Gk    begin Greek mode
 \\Rs    begin Russian mode
 \\Sb1   begin Symbol mode 1
 \\Sb2   begin Symbol mode 2

.PP
The following
.B chtext
commands need not be followed by a space.

 #       print a space in Chinese mode
 \\#      print # in Chinese mode
 =       appended to a pinyin syllable, 
            disables Chinese character selection
 \\=      print = in Chinese mode
 -       used as hyphen in multi-syllable combinations
 \\-      print - in Chinese mode
 \\@c     continue a long line
 \\Quiet  disable screen messages
 \\Show   enable screen messages

.PP
The following Chinese mode punctuation symbols are recognized by
.BR chtext .

 douh   (comma)
 dunh   (dun4-hao4, no English parallel) 
 juh    (hollow period)
 maoh   (colon)
 fenh   (semicolon)
 wenh   (question mark)
 ganth  (exclamation point)

.SH DOCUMENTATION
.PP
J. B. Wang's documentation file "A GUIDE TO CHTEXT" is 
.I chtext.doc 
in the directory 

.IR /usr/local/doc/ch .

There are some examples of CCDOS and pinyin files in
.IR /usr/local/doc/ch/examples .

.SH AUTHOR
Dr. J. B. Wang

jwang@pittvms.bitnet.

Dr. Wang would be pleased to hear of any suggestions for improving
.BR chtext .

This man page is by S. G. Simpson, simpson@math.psu.edu.

.SH BUGS
The
.B chtext 
program is still under development and fairly buggy. 

